from pdf4me.model import SwissQrCreatorReq, ReadBarcodes, SwissQrCreatorListReq


class SwissQRApi(object):

    def __init__(self, pdf4me_client):
        self.pdf4me_client = pdf4me_client

    def create_swiss_qr_bill(self, swiss_qr_creator_req):  
        """create_swiss_qr_bill  

        :param SwissQrCreatorReq swiss_qr_creator_req:
        :return: SwissQrCreatorRes
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object=swiss_qr_creator_req,
                                                                    controller='SwissQR/CreateSwissQrBill')

    def create_swiss_qr_bill_list(self, swiss_qr_creator_list_req):  
        """create_swiss_qr_bill_list  

        :param SwissQrCreatorListReq swiss_qr_creator_list_req:
        :return: SwissQrCreatorListRes
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object=swiss_qr_creator_list_req,
                                                                    controller='SwissQR/CreateSwissQrBillList')

    def read_swiss_qr_code(self, read_barcodes):  
        """read_swiss_qr_code  

        :param ReadBarcodes read_barcodes:
        :return: ReadBarcodesRes
                 If the method is called asynchronously,
                 returns the request thread.
        """
        return self.pdf4me_client.custom_http.post_universal_object(universal_object=read_barcodes,
                                                                    controller='SwissQR/ReadSwissQrCode')



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RotateConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'angle': 'float',
        'origin_x': 'int',
        'origin_y': 'int'
    }

    attribute_map = {
        'angle': 'angle',
        'origin_x': 'originX',
        'origin_y': 'originY'
    }

    def __init__(self, angle=None, origin_x=None, origin_y=None):  # noqa: E501
        """RotateConfig - a model defined in Swagger"""  # noqa: E501

        self._angle = None
        self._origin_x = None
        self._origin_y = None
        self.discriminator = None

        self.angle = angle
        self.origin_x = origin_x
        self.origin_y = origin_y

    @property
    def angle(self):
        """Gets the angle of this RotateConfig.  # noqa: E501


        :return: The angle of this RotateConfig.  # noqa: E501
        :rtype: float
        """
        return self._angle

    @angle.setter
    def angle(self, angle):
        """Sets the angle of this RotateConfig.


        :param angle: The angle of this RotateConfig.  # noqa: E501
        :type: float
        """
        if angle is None:
            raise ValueError("Invalid value for `angle`, must not be `None`")  # noqa: E501

        self._angle = angle

    @property
    def origin_x(self):
        """Gets the origin_x of this RotateConfig.  # noqa: E501


        :return: The origin_x of this RotateConfig.  # noqa: E501
        :rtype: int
        """
        return self._origin_x

    @origin_x.setter
    def origin_x(self, origin_x):
        """Sets the origin_x of this RotateConfig.


        :param origin_x: The origin_x of this RotateConfig.  # noqa: E501
        :type: int
        """
        if origin_x is None:
            raise ValueError("Invalid value for `origin_x`, must not be `None`")  # noqa: E501

        self._origin_x = origin_x

    @property
    def origin_y(self):
        """Gets the origin_y of this RotateConfig.  # noqa: E501


        :return: The origin_y of this RotateConfig.  # noqa: E501
        :rtype: int
        """
        return self._origin_y

    @origin_y.setter
    def origin_y(self, origin_y):
        """Sets the origin_y of this RotateConfig.


        :param origin_y: The origin_y of this RotateConfig.  # noqa: E501
        :type: int
        """
        if origin_y is None:
            raise ValueError("Invalid value for `origin_y`, must not be `None`")  # noqa: E501

        self._origin_y = origin_y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RotateConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RotateConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SwissQrCreatorAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'billing_data': 'BillingData',
        'language_type': 'str',
        'seperator_line': 'str',
        'format_type': 'str',
        'swiss_qr_on_pdf_required': 'bool',
        'action_id': 'str'
    }

    attribute_map = {
        'billing_data': 'billingData',
        'language_type': 'languageType',
        'seperator_line': 'seperatorLine',
        'format_type': 'formatType',
        'swiss_qr_on_pdf_required': 'swissQrOnPdfRequired',
        'action_id': 'actionId'
    }

    def __init__(self, billing_data=None, language_type=None, seperator_line=None, format_type=None, swiss_qr_on_pdf_required=None, action_id=None):  # noqa: E501
        """SwissQrCreatorAction - a model defined in Swagger"""  # noqa: E501

        self._billing_data = None
        self._language_type = None
        self._seperator_line = None
        self._format_type = None
        self._swiss_qr_on_pdf_required = None
        self._action_id = None
        self.discriminator = None

        if billing_data is not None:
            self.billing_data = billing_data
        if language_type is not None:
            self.language_type = language_type
        if seperator_line is not None:
            self.seperator_line = seperator_line
        if format_type is not None:
            self.format_type = format_type
        if swiss_qr_on_pdf_required is not None:
            self.swiss_qr_on_pdf_required = swiss_qr_on_pdf_required
        if action_id is not None:
            self.action_id = action_id

    @property
    def billing_data(self):
        """Gets the billing_data of this SwissQrCreatorAction.  # noqa: E501


        :return: The billing_data of this SwissQrCreatorAction.  # noqa: E501
        :rtype: BillingData
        """
        return self._billing_data

    @billing_data.setter
    def billing_data(self, billing_data):
        """Sets the billing_data of this SwissQrCreatorAction.


        :param billing_data: The billing_data of this SwissQrCreatorAction.  # noqa: E501
        :type: BillingData
        """

        self._billing_data = billing_data

    @property
    def language_type(self):
        """Gets the language_type of this SwissQrCreatorAction.  # noqa: E501


        :return: The language_type of this SwissQrCreatorAction.  # noqa: E501
        :rtype: str
        """
        return self._language_type

    @language_type.setter
    def language_type(self, language_type):
        """Sets the language_type of this SwissQrCreatorAction.


        :param language_type: The language_type of this SwissQrCreatorAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["german", "french", "italian", "english"]  # noqa: E501
        if language_type not in allowed_values:
            raise ValueError(
                "Invalid value for `language_type` ({0}), must be one of {1}"  # noqa: E501
                .format(language_type, allowed_values)
            )

        self._language_type = language_type

    @property
    def seperator_line(self):
        """Gets the seperator_line of this SwissQrCreatorAction.  # noqa: E501


        :return: The seperator_line of this SwissQrCreatorAction.  # noqa: E501
        :rtype: str
        """
        return self._seperator_line

    @seperator_line.setter
    def seperator_line(self, seperator_line):
        """Sets the seperator_line of this SwissQrCreatorAction.


        :param seperator_line: The seperator_line of this SwissQrCreatorAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["lineWithScissor", "line", "none"]  # noqa: E501
        if seperator_line not in allowed_values:
            raise ValueError(
                "Invalid value for `seperator_line` ({0}), must be one of {1}"  # noqa: E501
                .format(seperator_line, allowed_values)
            )

        self._seperator_line = seperator_line

    @property
    def format_type(self):
        """Gets the format_type of this SwissQrCreatorAction.  # noqa: E501


        :return: The format_type of this SwissQrCreatorAction.  # noqa: E501
        :rtype: str
        """
        return self._format_type

    @format_type.setter
    def format_type(self, format_type):
        """Sets the format_type of this SwissQrCreatorAction.


        :param format_type: The format_type of this SwissQrCreatorAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["tiff", "pDF", "sVG", "pNG", "jPEG"]  # noqa: E501
        if format_type not in allowed_values:
            raise ValueError(
                "Invalid value for `format_type` ({0}), must be one of {1}"  # noqa: E501
                .format(format_type, allowed_values)
            )

        self._format_type = format_type

    @property
    def swiss_qr_on_pdf_required(self):
        """Gets the swiss_qr_on_pdf_required of this SwissQrCreatorAction.  # noqa: E501


        :return: The swiss_qr_on_pdf_required of this SwissQrCreatorAction.  # noqa: E501
        :rtype: bool
        """
        return self._swiss_qr_on_pdf_required

    @swiss_qr_on_pdf_required.setter
    def swiss_qr_on_pdf_required(self, swiss_qr_on_pdf_required):
        """Sets the swiss_qr_on_pdf_required of this SwissQrCreatorAction.


        :param swiss_qr_on_pdf_required: The swiss_qr_on_pdf_required of this SwissQrCreatorAction.  # noqa: E501
        :type: bool
        """

        self._swiss_qr_on_pdf_required = swiss_qr_on_pdf_required

    @property
    def action_id(self):
        """Gets the action_id of this SwissQrCreatorAction.  # noqa: E501


        :return: The action_id of this SwissQrCreatorAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this SwissQrCreatorAction.


        :param action_id: The action_id of this SwissQrCreatorAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SwissQrCreatorAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwissQrCreatorAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocTemplate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'language': 'str',
        'sort_order': 'int',
        'process_type': 'str',
        'doc_type': 'str',
        'doc_template_set_id': 'str',
        'doc_render_type': 'str',
        'doc_template_content': 'str'
    }

    attribute_map = {
        'name': 'name',
        'language': 'language',
        'sort_order': 'sortOrder',
        'process_type': 'processType',
        'doc_type': 'docType',
        'doc_template_set_id': 'docTemplateSetId',
        'doc_render_type': 'docRenderType',
        'doc_template_content': 'docTemplateContent'
    }

    def __init__(self, name=None, language=None, sort_order=None, process_type=None, doc_type=None, doc_template_set_id=None, doc_render_type=None, doc_template_content=None):  # noqa: E501
        """DocTemplate - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._language = None
        self._sort_order = None
        self._process_type = None
        self._doc_type = None
        self._doc_template_set_id = None
        self._doc_render_type = None
        self._doc_template_content = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if language is not None:
            self.language = language
        if sort_order is not None:
            self.sort_order = sort_order
        if process_type is not None:
            self.process_type = process_type
        if doc_type is not None:
            self.doc_type = doc_type
        if doc_template_set_id is not None:
            self.doc_template_set_id = doc_template_set_id
        if doc_render_type is not None:
            self.doc_render_type = doc_render_type
        if doc_template_content is not None:
            self.doc_template_content = doc_template_content

    @property
    def name(self):
        """Gets the name of this DocTemplate.  # noqa: E501


        :return: The name of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocTemplate.


        :param name: The name of this DocTemplate.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def language(self):
        """Gets the language of this DocTemplate.  # noqa: E501


        :return: The language of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DocTemplate.


        :param language: The language of this DocTemplate.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def sort_order(self):
        """Gets the sort_order of this DocTemplate.  # noqa: E501


        :return: The sort_order of this DocTemplate.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this DocTemplate.


        :param sort_order: The sort_order of this DocTemplate.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    @property
    def process_type(self):
        """Gets the process_type of this DocTemplate.  # noqa: E501


        :return: The process_type of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._process_type

    @process_type.setter
    def process_type(self, process_type):
        """Sets the process_type of this DocTemplate.


        :param process_type: The process_type of this DocTemplate.  # noqa: E501
        :type: str
        """

        self._process_type = process_type

    @property
    def doc_type(self):
        """Gets the doc_type of this DocTemplate.  # noqa: E501


        :return: The doc_type of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._doc_type

    @doc_type.setter
    def doc_type(self, doc_type):
        """Sets the doc_type of this DocTemplate.


        :param doc_type: The doc_type of this DocTemplate.  # noqa: E501
        :type: str
        """

        self._doc_type = doc_type

    @property
    def doc_template_set_id(self):
        """Gets the doc_template_set_id of this DocTemplate.  # noqa: E501


        :return: The doc_template_set_id of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._doc_template_set_id

    @doc_template_set_id.setter
    def doc_template_set_id(self, doc_template_set_id):
        """Sets the doc_template_set_id of this DocTemplate.


        :param doc_template_set_id: The doc_template_set_id of this DocTemplate.  # noqa: E501
        :type: str
        """

        self._doc_template_set_id = doc_template_set_id

    @property
    def doc_render_type(self):
        """Gets the doc_render_type of this DocTemplate.  # noqa: E501


        :return: The doc_render_type of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._doc_render_type

    @doc_render_type.setter
    def doc_render_type(self, doc_render_type):
        """Sets the doc_render_type of this DocTemplate.


        :param doc_render_type: The doc_render_type of this DocTemplate.  # noqa: E501
        :type: str
        """
        allowed_values = ["undef", "wordMailMerge", "pdfStatic", "pdfForm", "excel", "report"]  # noqa: E501
        if doc_render_type not in allowed_values:
            raise ValueError(
                "Invalid value for `doc_render_type` ({0}), must be one of {1}"  # noqa: E501
                .format(doc_render_type, allowed_values)
            )

        self._doc_render_type = doc_render_type

    @property
    def doc_template_content(self):
        """Gets the doc_template_content of this DocTemplate.  # noqa: E501


        :return: The doc_template_content of this DocTemplate.  # noqa: E501
        :rtype: str
        """
        return self._doc_template_content

    @doc_template_content.setter
    def doc_template_content(self, doc_template_content):
        """Sets the doc_template_content of this DocTemplate.


        :param doc_template_content: The doc_template_content of this DocTemplate.  # noqa: E501
        :type: str
        """
        if doc_template_content is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', doc_template_content):  # noqa: E501
            raise ValueError(r"Invalid value for `doc_template_content`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._doc_template_content = doc_template_content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocTemplate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MailingAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'doc_templates': 'list[DocTemplate]',
        'mailing_config': 'MailingConfig',
        'excel_data': 'str',
        'start_immediate': 'bool',
        'generate_single_pdf': 'bool',
        'action_id': 'str'
    }

    attribute_map = {
        'doc_templates': 'docTemplates',
        'mailing_config': 'mailingConfig',
        'excel_data': 'excelData',
        'start_immediate': 'startImmediate',
        'generate_single_pdf': 'generateSinglePDF',
        'action_id': 'actionId'
    }

    def __init__(self, doc_templates=None, mailing_config=None, excel_data=None, start_immediate=None, generate_single_pdf=None, action_id=None):  # noqa: E501
        """MailingAction - a model defined in Swagger"""  # noqa: E501

        self._doc_templates = None
        self._mailing_config = None
        self._excel_data = None
        self._start_immediate = None
        self._generate_single_pdf = None
        self._action_id = None
        self.discriminator = None

        if doc_templates is not None:
            self.doc_templates = doc_templates
        if mailing_config is not None:
            self.mailing_config = mailing_config
        if excel_data is not None:
            self.excel_data = excel_data
        if start_immediate is not None:
            self.start_immediate = start_immediate
        if generate_single_pdf is not None:
            self.generate_single_pdf = generate_single_pdf
        if action_id is not None:
            self.action_id = action_id

    @property
    def doc_templates(self):
        """Gets the doc_templates of this MailingAction.  # noqa: E501


        :return: The doc_templates of this MailingAction.  # noqa: E501
        :rtype: list[DocTemplate]
        """
        return self._doc_templates

    @doc_templates.setter
    def doc_templates(self, doc_templates):
        """Sets the doc_templates of this MailingAction.


        :param doc_templates: The doc_templates of this MailingAction.  # noqa: E501
        :type: list[DocTemplate]
        """

        self._doc_templates = doc_templates

    @property
    def mailing_config(self):
        """Gets the mailing_config of this MailingAction.  # noqa: E501


        :return: The mailing_config of this MailingAction.  # noqa: E501
        :rtype: MailingConfig
        """
        return self._mailing_config

    @mailing_config.setter
    def mailing_config(self, mailing_config):
        """Sets the mailing_config of this MailingAction.


        :param mailing_config: The mailing_config of this MailingAction.  # noqa: E501
        :type: MailingConfig
        """

        self._mailing_config = mailing_config

    @property
    def excel_data(self):
        """Gets the excel_data of this MailingAction.  # noqa: E501


        :return: The excel_data of this MailingAction.  # noqa: E501
        :rtype: str
        """
        return self._excel_data

    @excel_data.setter
    def excel_data(self, excel_data):
        """Sets the excel_data of this MailingAction.


        :param excel_data: The excel_data of this MailingAction.  # noqa: E501
        :type: str
        """
        if excel_data is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', excel_data):  # noqa: E501
            raise ValueError(r"Invalid value for `excel_data`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._excel_data = excel_data

    @property
    def start_immediate(self):
        """Gets the start_immediate of this MailingAction.  # noqa: E501


        :return: The start_immediate of this MailingAction.  # noqa: E501
        :rtype: bool
        """
        return self._start_immediate

    @start_immediate.setter
    def start_immediate(self, start_immediate):
        """Sets the start_immediate of this MailingAction.


        :param start_immediate: The start_immediate of this MailingAction.  # noqa: E501
        :type: bool
        """

        self._start_immediate = start_immediate

    @property
    def generate_single_pdf(self):
        """Gets the generate_single_pdf of this MailingAction.  # noqa: E501


        :return: The generate_single_pdf of this MailingAction.  # noqa: E501
        :rtype: bool
        """
        return self._generate_single_pdf

    @generate_single_pdf.setter
    def generate_single_pdf(self, generate_single_pdf):
        """Sets the generate_single_pdf of this MailingAction.


        :param generate_single_pdf: The generate_single_pdf of this MailingAction.  # noqa: E501
        :type: bool
        """

        self._generate_single_pdf = generate_single_pdf

    @property
    def action_id(self):
        """Gets the action_id of this MailingAction.  # noqa: E501


        :return: The action_id of this MailingAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this MailingAction.


        :param action_id: The action_id of this MailingAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MailingAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MailingAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ConvertFromPdfAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'output_format': 'str',
        'quality_type': 'str',
        'single_page': 'bool',
        'doc_author': 'str',
        'doc_title': 'str',
        'cover_thumbnail': 'str',
        'action_id': 'str'
    }

    attribute_map = {
        'output_format': 'outputFormat',
        'quality_type': 'qualityType',
        'single_page': 'singlePage',
        'doc_author': 'docAuthor',
        'doc_title': 'docTitle',
        'cover_thumbnail': 'coverThumbnail',
        'action_id': 'actionId'
    }

    def __init__(self, output_format=None, quality_type=None, single_page=None, doc_author=None, doc_title=None, cover_thumbnail=None, action_id=None):  # noqa: E501
        """ConvertFromPdfAction - a model defined in Swagger"""  # noqa: E501

        self._output_format = None
        self._quality_type = None
        self._single_page = None
        self._doc_author = None
        self._doc_title = None
        self._cover_thumbnail = None
        self._action_id = None
        self.discriminator = None

        if output_format is not None:
            self.output_format = output_format
        if quality_type is not None:
            self.quality_type = quality_type
        if single_page is not None:
            self.single_page = single_page
        if doc_author is not None:
            self.doc_author = doc_author
        if doc_title is not None:
            self.doc_title = doc_title
        if cover_thumbnail is not None:
            self.cover_thumbnail = cover_thumbnail
        if action_id is not None:
            self.action_id = action_id

    @property
    def output_format(self):
        """Gets the output_format of this ConvertFromPdfAction.  # noqa: E501


        :return: The output_format of this ConvertFromPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._output_format

    @output_format.setter
    def output_format(self, output_format):
        """Sets the output_format of this ConvertFromPdfAction.


        :param output_format: The output_format of this ConvertFromPdfAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["none", "docX", "excel", "pptx", "pdfOcr", "textOcr", "epub", "mobi"]  # noqa: E501
        if output_format not in allowed_values:
            raise ValueError(
                "Invalid value for `output_format` ({0}), must be one of {1}"  # noqa: E501
                .format(output_format, allowed_values)
            )

        self._output_format = output_format

    @property
    def quality_type(self):
        """Gets the quality_type of this ConvertFromPdfAction.  # noqa: E501


        :return: The quality_type of this ConvertFromPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._quality_type

    @quality_type.setter
    def quality_type(self, quality_type):
        """Sets the quality_type of this ConvertFromPdfAction.


        :param quality_type: The quality_type of this ConvertFromPdfAction.  # noqa: E501
        :type: str
        """
        allowed_values = ["draft", "high"]  # noqa: E501
        if quality_type not in allowed_values:
            raise ValueError(
                "Invalid value for `quality_type` ({0}), must be one of {1}"  # noqa: E501
                .format(quality_type, allowed_values)
            )

        self._quality_type = quality_type

    @property
    def single_page(self):
        """Gets the single_page of this ConvertFromPdfAction.  # noqa: E501


        :return: The single_page of this ConvertFromPdfAction.  # noqa: E501
        :rtype: bool
        """
        return self._single_page

    @single_page.setter
    def single_page(self, single_page):
        """Sets the single_page of this ConvertFromPdfAction.


        :param single_page: The single_page of this ConvertFromPdfAction.  # noqa: E501
        :type: bool
        """

        self._single_page = single_page

    @property
    def doc_author(self):
        """Gets the doc_author of this ConvertFromPdfAction.  # noqa: E501


        :return: The doc_author of this ConvertFromPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._doc_author

    @doc_author.setter
    def doc_author(self, doc_author):
        """Sets the doc_author of this ConvertFromPdfAction.


        :param doc_author: The doc_author of this ConvertFromPdfAction.  # noqa: E501
        :type: str
        """

        self._doc_author = doc_author

    @property
    def doc_title(self):
        """Gets the doc_title of this ConvertFromPdfAction.  # noqa: E501


        :return: The doc_title of this ConvertFromPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._doc_title

    @doc_title.setter
    def doc_title(self, doc_title):
        """Sets the doc_title of this ConvertFromPdfAction.


        :param doc_title: The doc_title of this ConvertFromPdfAction.  # noqa: E501
        :type: str
        """

        self._doc_title = doc_title

    @property
    def cover_thumbnail(self):
        """Gets the cover_thumbnail of this ConvertFromPdfAction.  # noqa: E501


        :return: The cover_thumbnail of this ConvertFromPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._cover_thumbnail

    @cover_thumbnail.setter
    def cover_thumbnail(self, cover_thumbnail):
        """Sets the cover_thumbnail of this ConvertFromPdfAction.


        :param cover_thumbnail: The cover_thumbnail of this ConvertFromPdfAction.  # noqa: E501
        :type: str
        """
        if cover_thumbnail is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', cover_thumbnail):  # noqa: E501
            raise ValueError("Invalid value for `cover_thumbnail`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._cover_thumbnail = cover_thumbnail

    @property
    def action_id(self):
        """Gets the action_id of this ConvertFromPdfAction.  # noqa: E501


        :return: The action_id of this ConvertFromPdfAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this ConvertFromPdfAction.


        :param action_id: The action_id of this ConvertFromPdfAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConvertFromPdfAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConvertFromPdfAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BillingData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'qr_type': 'str',
        'version': 'str',
        'coding_type': 'str',
        'iban': 'str',
        'cr_address_type': 'str',
        'cr_name': 'str',
        'cr_street_or_address_line1': 'str',
        'cr_build_no_or_address_line2': 'str',
        'cr_postal_code': 'str',
        'cr_city': 'str',
        'cr_country': 'str',
        'ucr_address_type': 'str',
        'ucr_name': 'str',
        'ucr_street_or_address_line1': 'str',
        'ucr_build_no_or_address_line2': 'str',
        'ucr_postal_code': 'str',
        'ucr_city': 'str',
        'ucr_country': 'str',
        'amount': 'float',
        'currency': 'str',
        'ud_address_type': 'str',
        'ud_name': 'str',
        'ud_street_or_address_line1': 'str',
        'ud_build_no_or_address_line2': 'str',
        'ud_postal_code': 'str',
        'ud_city': 'str',
        'ud_country': 'str',
        'reference_type': 'str',
        'reference': 'str',
        'unstructured_message': 'str',
        'billing_info': 'str',
        'av1_parameters': 'str',
        'av2_parameters': 'str'
    }

    attribute_map = {
        'qr_type': 'qrType',
        'version': 'version',
        'coding_type': 'codingType',
        'iban': 'iban',
        'cr_address_type': 'cr_AddressType',
        'cr_name': 'cr_Name',
        'cr_street_or_address_line1': 'cr_StreetOrAddressLine1',
        'cr_build_no_or_address_line2': 'cr_BuildNoOrAddressLine2',
        'cr_postal_code': 'cr_PostalCode',
        'cr_city': 'cr_City',
        'cr_country': 'cr_Country',
        'ucr_address_type': 'ucr_AddressType',
        'ucr_name': 'ucr_Name',
        'ucr_street_or_address_line1': 'ucr_StreetOrAddressLine1',
        'ucr_build_no_or_address_line2': 'ucr_BuildNoOrAddressLine2',
        'ucr_postal_code': 'ucr_PostalCode',
        'ucr_city': 'ucr_City',
        'ucr_country': 'ucr_Country',
        'amount': 'amount',
        'currency': 'currency',
        'ud_address_type': 'ud_AddressType',
        'ud_name': 'ud_Name',
        'ud_street_or_address_line1': 'ud_StreetOrAddressLine1',
        'ud_build_no_or_address_line2': 'ud_BuildNoOrAddressLine2',
        'ud_postal_code': 'ud_PostalCode',
        'ud_city': 'ud_City',
        'ud_country': 'ud_Country',
        'reference_type': 'referenceType',
        'reference': 'reference',
        'unstructured_message': 'unstructuredMessage',
        'billing_info': 'billingInfo',
        'av1_parameters': 'av1_Parameters',
        'av2_parameters': 'av2_Parameters'
    }

    def __init__(self, qr_type=None, version=None, coding_type=None, iban=None, cr_address_type=None, cr_name=None, cr_street_or_address_line1=None, cr_build_no_or_address_line2=None, cr_postal_code=None, cr_city=None, cr_country=None, ucr_address_type=None, ucr_name=None, ucr_street_or_address_line1=None, ucr_build_no_or_address_line2=None, ucr_postal_code=None, ucr_city=None, ucr_country=None, amount=None, currency=None, ud_address_type=None, ud_name=None, ud_street_or_address_line1=None, ud_build_no_or_address_line2=None, ud_postal_code=None, ud_city=None, ud_country=None, reference_type=None, reference=None, unstructured_message=None, billing_info=None, av1_parameters=None, av2_parameters=None):  # noqa: E501
        """BillingData - a model defined in Swagger"""  # noqa: E501

        self._qr_type = None
        self._version = None
        self._coding_type = None
        self._iban = None
        self._cr_address_type = None
        self._cr_name = None
        self._cr_street_or_address_line1 = None
        self._cr_build_no_or_address_line2 = None
        self._cr_postal_code = None
        self._cr_city = None
        self._cr_country = None
        self._ucr_address_type = None
        self._ucr_name = None
        self._ucr_street_or_address_line1 = None
        self._ucr_build_no_or_address_line2 = None
        self._ucr_postal_code = None
        self._ucr_city = None
        self._ucr_country = None
        self._amount = None
        self._currency = None
        self._ud_address_type = None
        self._ud_name = None
        self._ud_street_or_address_line1 = None
        self._ud_build_no_or_address_line2 = None
        self._ud_postal_code = None
        self._ud_city = None
        self._ud_country = None
        self._reference_type = None
        self._reference = None
        self._unstructured_message = None
        self._billing_info = None
        self._av1_parameters = None
        self._av2_parameters = None
        self.discriminator = None

        if qr_type is not None:
            self.qr_type = qr_type
        if version is not None:
            self.version = version
        if coding_type is not None:
            self.coding_type = coding_type
        if iban is not None:
            self.iban = iban
        if cr_address_type is not None:
            self.cr_address_type = cr_address_type
        if cr_name is not None:
            self.cr_name = cr_name
        if cr_street_or_address_line1 is not None:
            self.cr_street_or_address_line1 = cr_street_or_address_line1
        if cr_build_no_or_address_line2 is not None:
            self.cr_build_no_or_address_line2 = cr_build_no_or_address_line2
        if cr_postal_code is not None:
            self.cr_postal_code = cr_postal_code
        if cr_city is not None:
            self.cr_city = cr_city
        if cr_country is not None:
            self.cr_country = cr_country
        if ucr_address_type is not None:
            self.ucr_address_type = ucr_address_type
        if ucr_name is not None:
            self.ucr_name = ucr_name
        if ucr_street_or_address_line1 is not None:
            self.ucr_street_or_address_line1 = ucr_street_or_address_line1
        if ucr_build_no_or_address_line2 is not None:
            self.ucr_build_no_or_address_line2 = ucr_build_no_or_address_line2
        if ucr_postal_code is not None:
            self.ucr_postal_code = ucr_postal_code
        if ucr_city is not None:
            self.ucr_city = ucr_city
        if ucr_country is not None:
            self.ucr_country = ucr_country
        if amount is not None:
            self.amount = amount
        if currency is not None:
            self.currency = currency
        if ud_address_type is not None:
            self.ud_address_type = ud_address_type
        if ud_name is not None:
            self.ud_name = ud_name
        if ud_street_or_address_line1 is not None:
            self.ud_street_or_address_line1 = ud_street_or_address_line1
        if ud_build_no_or_address_line2 is not None:
            self.ud_build_no_or_address_line2 = ud_build_no_or_address_line2
        if ud_postal_code is not None:
            self.ud_postal_code = ud_postal_code
        if ud_city is not None:
            self.ud_city = ud_city
        if ud_country is not None:
            self.ud_country = ud_country
        if reference_type is not None:
            self.reference_type = reference_type
        if reference is not None:
            self.reference = reference
        if unstructured_message is not None:
            self.unstructured_message = unstructured_message
        if billing_info is not None:
            self.billing_info = billing_info
        if av1_parameters is not None:
            self.av1_parameters = av1_parameters
        if av2_parameters is not None:
            self.av2_parameters = av2_parameters

    @property
    def qr_type(self):
        """Gets the qr_type of this BillingData.  # noqa: E501


        :return: The qr_type of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._qr_type

    @qr_type.setter
    def qr_type(self, qr_type):
        """Sets the qr_type of this BillingData.


        :param qr_type: The qr_type of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["sPC"]  # noqa: E501
        if qr_type not in allowed_values:
            raise ValueError(
                "Invalid value for `qr_type` ({0}), must be one of {1}"  # noqa: E501
                .format(qr_type, allowed_values)
            )

        self._qr_type = qr_type

    @property
    def version(self):
        """Gets the version of this BillingData.  # noqa: E501


        :return: The version of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this BillingData.


        :param version: The version of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["v20"]  # noqa: E501
        if version not in allowed_values:
            raise ValueError(
                "Invalid value for `version` ({0}), must be one of {1}"  # noqa: E501
                .format(version, allowed_values)
            )

        self._version = version

    @property
    def coding_type(self):
        """Gets the coding_type of this BillingData.  # noqa: E501


        :return: The coding_type of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._coding_type

    @coding_type.setter
    def coding_type(self, coding_type):
        """Sets the coding_type of this BillingData.


        :param coding_type: The coding_type of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["default", "uTF8"]  # noqa: E501
        if coding_type not in allowed_values:
            raise ValueError(
                "Invalid value for `coding_type` ({0}), must be one of {1}"  # noqa: E501
                .format(coding_type, allowed_values)
            )

        self._coding_type = coding_type

    @property
    def iban(self):
        """Gets the iban of this BillingData.  # noqa: E501


        :return: The iban of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._iban

    @iban.setter
    def iban(self, iban):
        """Sets the iban of this BillingData.


        :param iban: The iban of this BillingData.  # noqa: E501
        :type: str
        """
        if iban is not None and len(iban) > 21:
            raise ValueError("Invalid value for `iban`, length must be less than or equal to `21`")  # noqa: E501

        self._iban = iban

    @property
    def cr_address_type(self):
        """Gets the cr_address_type of this BillingData.  # noqa: E501


        :return: The cr_address_type of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_address_type

    @cr_address_type.setter
    def cr_address_type(self, cr_address_type):
        """Sets the cr_address_type of this BillingData.


        :param cr_address_type: The cr_address_type of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["s", "k"]  # noqa: E501
        if cr_address_type not in allowed_values:
            raise ValueError(
                "Invalid value for `cr_address_type` ({0}), must be one of {1}"  # noqa: E501
                .format(cr_address_type, allowed_values)
            )

        self._cr_address_type = cr_address_type

    @property
    def cr_name(self):
        """Gets the cr_name of this BillingData.  # noqa: E501


        :return: The cr_name of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_name

    @cr_name.setter
    def cr_name(self, cr_name):
        """Sets the cr_name of this BillingData.


        :param cr_name: The cr_name of this BillingData.  # noqa: E501
        :type: str
        """
        if cr_name is not None and len(cr_name) > 70:
            raise ValueError("Invalid value for `cr_name`, length must be less than or equal to `70`")  # noqa: E501

        self._cr_name = cr_name

    @property
    def cr_street_or_address_line1(self):
        """Gets the cr_street_or_address_line1 of this BillingData.  # noqa: E501


        :return: The cr_street_or_address_line1 of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_street_or_address_line1

    @cr_street_or_address_line1.setter
    def cr_street_or_address_line1(self, cr_street_or_address_line1):
        """Sets the cr_street_or_address_line1 of this BillingData.


        :param cr_street_or_address_line1: The cr_street_or_address_line1 of this BillingData.  # noqa: E501
        :type: str
        """
        if cr_street_or_address_line1 is not None and len(cr_street_or_address_line1) > 70:
            raise ValueError("Invalid value for `cr_street_or_address_line1`, length must be less than or equal to `70`")  # noqa: E501

        self._cr_street_or_address_line1 = cr_street_or_address_line1

    @property
    def cr_build_no_or_address_line2(self):
        """Gets the cr_build_no_or_address_line2 of this BillingData.  # noqa: E501


        :return: The cr_build_no_or_address_line2 of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_build_no_or_address_line2

    @cr_build_no_or_address_line2.setter
    def cr_build_no_or_address_line2(self, cr_build_no_or_address_line2):
        """Sets the cr_build_no_or_address_line2 of this BillingData.


        :param cr_build_no_or_address_line2: The cr_build_no_or_address_line2 of this BillingData.  # noqa: E501
        :type: str
        """
        if cr_build_no_or_address_line2 is not None and len(cr_build_no_or_address_line2) > 70:
            raise ValueError("Invalid value for `cr_build_no_or_address_line2`, length must be less than or equal to `70`")  # noqa: E501

        self._cr_build_no_or_address_line2 = cr_build_no_or_address_line2

    @property
    def cr_postal_code(self):
        """Gets the cr_postal_code of this BillingData.  # noqa: E501


        :return: The cr_postal_code of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_postal_code

    @cr_postal_code.setter
    def cr_postal_code(self, cr_postal_code):
        """Sets the cr_postal_code of this BillingData.


        :param cr_postal_code: The cr_postal_code of this BillingData.  # noqa: E501
        :type: str
        """
        if cr_postal_code is not None and len(cr_postal_code) > 16:
            raise ValueError("Invalid value for `cr_postal_code`, length must be less than or equal to `16`")  # noqa: E501

        self._cr_postal_code = cr_postal_code

    @property
    def cr_city(self):
        """Gets the cr_city of this BillingData.  # noqa: E501


        :return: The cr_city of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_city

    @cr_city.setter
    def cr_city(self, cr_city):
        """Sets the cr_city of this BillingData.


        :param cr_city: The cr_city of this BillingData.  # noqa: E501
        :type: str
        """
        if cr_city is not None and len(cr_city) > 35:
            raise ValueError("Invalid value for `cr_city`, length must be less than or equal to `35`")  # noqa: E501

        self._cr_city = cr_city

    @property
    def cr_country(self):
        """Gets the cr_country of this BillingData.  # noqa: E501


        :return: The cr_country of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._cr_country

    @cr_country.setter
    def cr_country(self, cr_country):
        """Sets the cr_country of this BillingData.


        :param cr_country: The cr_country of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["andorra", "unitedArabEmirates", "afghanistan", "antiguaandBarbuda", "anguilla", "albania", "armenia", "angola", "antarctica", "argentina", "americanSamoa", "austria", "australia", "aruba", "ålandIslands", "azerbaijan", "bosniaandHerzegovina", "barbados", "bangladesh", "belgium", "burkinaFaso", "bulgaria", "bahrain", "burundi", "benin", "saintBarthélemy", "bermuda", "bruneiDarussalam", "boliviaPlurinationalStateof", "bonaireSintEustatiusandSaba", "brazil", "bahamas", "bhutan", "bouvetIsland", "botswana", "belarus", "belize", "canada", "cocosKeelingIslands", "congoDemocraticRepublicofthe", "centralAfricanRepublic", "congo", "switzerland", "côtedIvoire", "cookIslands", "chile", "cameroon", "china", "colombia", "costaRica", "cuba", "caboVerde", "curaçao", "christmasIsland", "cyprus", "czechia", "germany", "djibouti", "denmark", "dominica", "dominicanRepublic", "algeria", "ecuador", "estonia", "egypt", "westernSahara", "eritrea", "spain", "ethiopia", "finland", "fiji", "falklandIslandsMalvinas", "micronesiaFederatedStatesof", "faroeIslands", "france", "gabon", "unitedKingdomofGreatBritainandNorthernIreland", "grenada", "georgia", "frenchGuiana", "guernsey", "ghana", "gibraltar", "greenland", "gambia", "guinea", "guadeloupe", "equatorialGuinea", "greece", "southGeorgiaandtheSouthSandwichIslands", "guatemala", "guam", "guineaBissau", "guyana", "hongKong", "heardIslandandMcDonaldIslands", "honduras", "croatia", "haiti", "hungary", "indonesia", "ireland", "israel", "isleofMan", "india", "britishIndianOceanTerritory", "iraq", "iranIslamicRepublicof", "iceland", "italy", "jersey", "jamaica", "jordan", "japan", "kenya", "kyrgyzstan", "cambodia", "kiribati", "comoros", "saintKittsandNevis", "koreaDemocraticPeoplesRepublicof", "koreaRepublicof", "kuwait", "caymanIslands", "kazakhstan", "laoPeoplesDemocraticRepublic", "lebanon", "saintLucia", "liechtenstein", "sriLanka", "liberia", "lesotho", "lithuania", "luxembourg", "latvia", "libya", "morocco", "monaco", "moldovaRepublicof", "montenegro", "saintMartinFrenchpart", "madagascar", "marshallIslands", "northMacedonia", "mali", "myanmar", "mongolia", "macao", "northernMarianaIslands", "martinique", "mauritania", "montserrat", "malta", "mauritius", "maldives", "malawi", "mexico", "malaysia", "mozambique", "namibia", "newCaledonia", "niger", "norfolkIsland", "nigeria", "nicaragua", "netherlands", "norway", "nepal", "nauru", "niue", "newZealand", "oman", "panama", "peru", "frenchPolynesia", "papuaNewGuinea", "philippines", "pakistan", "poland", "saintPierreandMiquelon", "pitcairn", "puertoRico", "palestineStateof", "portugal", "palau", "paraguay", "qatar", "réunion", "romania", "serbia", "russianFederation", "rwanda", "saudiArabia", "solomonIslands", "seychelles", "sudan", "sweden", "singapore", "saintHelenaAscensionandTristandaCunha", "slovenia", "svalbardandJanMayen", "slovakia", "sierraLeone", "sanMarino", "senegal", "somalia", "suriname", "southSudan", "saoTomeandPrincipe", "elSalvador", "sintMaartenDutchpart", "syrianArabRepublic", "eswatini", "turksandCaicosIslands", "chad", "frenchSouthernTerritories", "togo", "thailand", "tajikistan", "tokelau", "timorLeste", "turkmenistan", "tunisia", "tonga", "turkey", "trinidadandTobago", "tuvalu", "taiwanProvinceofChina", "tanzaniaUnitedRepublicof", "ukraine", "uganda", "unitedStatesMinorOutlyingIslands", "unitedStatesofAmerica", "uruguay", "uzbekistan", "holySee", "saintVincentandtheGrenadines", "venezuelaBolivarianRepublicof", "virginIslandsBritish", "virginIslandsUS", "vietNam", "vanuatu", "wallisandFutuna", "samoa", "yemen", "mayotte", "southAfrica", "zambia", "zimbabwe"]  # noqa: E501
        if cr_country not in allowed_values:
            raise ValueError(
                "Invalid value for `cr_country` ({0}), must be one of {1}"  # noqa: E501
                .format(cr_country, allowed_values)
            )

        self._cr_country = cr_country

    @property
    def ucr_address_type(self):
        """Gets the ucr_address_type of this BillingData.  # noqa: E501


        :return: The ucr_address_type of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_address_type

    @ucr_address_type.setter
    def ucr_address_type(self, ucr_address_type):
        """Sets the ucr_address_type of this BillingData.


        :param ucr_address_type: The ucr_address_type of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["s", "k"]  # noqa: E501
        if ucr_address_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ucr_address_type` ({0}), must be one of {1}"  # noqa: E501
                .format(ucr_address_type, allowed_values)
            )

        self._ucr_address_type = ucr_address_type

    @property
    def ucr_name(self):
        """Gets the ucr_name of this BillingData.  # noqa: E501


        :return: The ucr_name of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_name

    @ucr_name.setter
    def ucr_name(self, ucr_name):
        """Sets the ucr_name of this BillingData.


        :param ucr_name: The ucr_name of this BillingData.  # noqa: E501
        :type: str
        """
        if ucr_name is not None and len(ucr_name) > 70:
            raise ValueError("Invalid value for `ucr_name`, length must be less than or equal to `70`")  # noqa: E501

        self._ucr_name = ucr_name

    @property
    def ucr_street_or_address_line1(self):
        """Gets the ucr_street_or_address_line1 of this BillingData.  # noqa: E501


        :return: The ucr_street_or_address_line1 of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_street_or_address_line1

    @ucr_street_or_address_line1.setter
    def ucr_street_or_address_line1(self, ucr_street_or_address_line1):
        """Sets the ucr_street_or_address_line1 of this BillingData.


        :param ucr_street_or_address_line1: The ucr_street_or_address_line1 of this BillingData.  # noqa: E501
        :type: str
        """
        if ucr_street_or_address_line1 is not None and len(ucr_street_or_address_line1) > 70:
            raise ValueError("Invalid value for `ucr_street_or_address_line1`, length must be less than or equal to `70`")  # noqa: E501

        self._ucr_street_or_address_line1 = ucr_street_or_address_line1

    @property
    def ucr_build_no_or_address_line2(self):
        """Gets the ucr_build_no_or_address_line2 of this BillingData.  # noqa: E501


        :return: The ucr_build_no_or_address_line2 of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_build_no_or_address_line2

    @ucr_build_no_or_address_line2.setter
    def ucr_build_no_or_address_line2(self, ucr_build_no_or_address_line2):
        """Sets the ucr_build_no_or_address_line2 of this BillingData.


        :param ucr_build_no_or_address_line2: The ucr_build_no_or_address_line2 of this BillingData.  # noqa: E501
        :type: str
        """
        if ucr_build_no_or_address_line2 is not None and len(ucr_build_no_or_address_line2) > 70:
            raise ValueError("Invalid value for `ucr_build_no_or_address_line2`, length must be less than or equal to `70`")  # noqa: E501

        self._ucr_build_no_or_address_line2 = ucr_build_no_or_address_line2

    @property
    def ucr_postal_code(self):
        """Gets the ucr_postal_code of this BillingData.  # noqa: E501


        :return: The ucr_postal_code of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_postal_code

    @ucr_postal_code.setter
    def ucr_postal_code(self, ucr_postal_code):
        """Sets the ucr_postal_code of this BillingData.


        :param ucr_postal_code: The ucr_postal_code of this BillingData.  # noqa: E501
        :type: str
        """
        if ucr_postal_code is not None and len(ucr_postal_code) > 16:
            raise ValueError("Invalid value for `ucr_postal_code`, length must be less than or equal to `16`")  # noqa: E501

        self._ucr_postal_code = ucr_postal_code

    @property
    def ucr_city(self):
        """Gets the ucr_city of this BillingData.  # noqa: E501


        :return: The ucr_city of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_city

    @ucr_city.setter
    def ucr_city(self, ucr_city):
        """Sets the ucr_city of this BillingData.


        :param ucr_city: The ucr_city of this BillingData.  # noqa: E501
        :type: str
        """
        if ucr_city is not None and len(ucr_city) > 35:
            raise ValueError("Invalid value for `ucr_city`, length must be less than or equal to `35`")  # noqa: E501

        self._ucr_city = ucr_city

    @property
    def ucr_country(self):
        """Gets the ucr_country of this BillingData.  # noqa: E501


        :return: The ucr_country of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ucr_country

    @ucr_country.setter
    def ucr_country(self, ucr_country):
        """Sets the ucr_country of this BillingData.


        :param ucr_country: The ucr_country of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["andorra", "unitedArabEmirates", "afghanistan", "antiguaandBarbuda", "anguilla", "albania", "armenia", "angola", "antarctica", "argentina", "americanSamoa", "austria", "australia", "aruba", "ålandIslands", "azerbaijan", "bosniaandHerzegovina", "barbados", "bangladesh", "belgium", "burkinaFaso", "bulgaria", "bahrain", "burundi", "benin", "saintBarthélemy", "bermuda", "bruneiDarussalam", "boliviaPlurinationalStateof", "bonaireSintEustatiusandSaba", "brazil", "bahamas", "bhutan", "bouvetIsland", "botswana", "belarus", "belize", "canada", "cocosKeelingIslands", "congoDemocraticRepublicofthe", "centralAfricanRepublic", "congo", "switzerland", "côtedIvoire", "cookIslands", "chile", "cameroon", "china", "colombia", "costaRica", "cuba", "caboVerde", "curaçao", "christmasIsland", "cyprus", "czechia", "germany", "djibouti", "denmark", "dominica", "dominicanRepublic", "algeria", "ecuador", "estonia", "egypt", "westernSahara", "eritrea", "spain", "ethiopia", "finland", "fiji", "falklandIslandsMalvinas", "micronesiaFederatedStatesof", "faroeIslands", "france", "gabon", "unitedKingdomofGreatBritainandNorthernIreland", "grenada", "georgia", "frenchGuiana", "guernsey", "ghana", "gibraltar", "greenland", "gambia", "guinea", "guadeloupe", "equatorialGuinea", "greece", "southGeorgiaandtheSouthSandwichIslands", "guatemala", "guam", "guineaBissau", "guyana", "hongKong", "heardIslandandMcDonaldIslands", "honduras", "croatia", "haiti", "hungary", "indonesia", "ireland", "israel", "isleofMan", "india", "britishIndianOceanTerritory", "iraq", "iranIslamicRepublicof", "iceland", "italy", "jersey", "jamaica", "jordan", "japan", "kenya", "kyrgyzstan", "cambodia", "kiribati", "comoros", "saintKittsandNevis", "koreaDemocraticPeoplesRepublicof", "koreaRepublicof", "kuwait", "caymanIslands", "kazakhstan", "laoPeoplesDemocraticRepublic", "lebanon", "saintLucia", "liechtenstein", "sriLanka", "liberia", "lesotho", "lithuania", "luxembourg", "latvia", "libya", "morocco", "monaco", "moldovaRepublicof", "montenegro", "saintMartinFrenchpart", "madagascar", "marshallIslands", "northMacedonia", "mali", "myanmar", "mongolia", "macao", "northernMarianaIslands", "martinique", "mauritania", "montserrat", "malta", "mauritius", "maldives", "malawi", "mexico", "malaysia", "mozambique", "namibia", "newCaledonia", "niger", "norfolkIsland", "nigeria", "nicaragua", "netherlands", "norway", "nepal", "nauru", "niue", "newZealand", "oman", "panama", "peru", "frenchPolynesia", "papuaNewGuinea", "philippines", "pakistan", "poland", "saintPierreandMiquelon", "pitcairn", "puertoRico", "palestineStateof", "portugal", "palau", "paraguay", "qatar", "réunion", "romania", "serbia", "russianFederation", "rwanda", "saudiArabia", "solomonIslands", "seychelles", "sudan", "sweden", "singapore", "saintHelenaAscensionandTristandaCunha", "slovenia", "svalbardandJanMayen", "slovakia", "sierraLeone", "sanMarino", "senegal", "somalia", "suriname", "southSudan", "saoTomeandPrincipe", "elSalvador", "sintMaartenDutchpart", "syrianArabRepublic", "eswatini", "turksandCaicosIslands", "chad", "frenchSouthernTerritories", "togo", "thailand", "tajikistan", "tokelau", "timorLeste", "turkmenistan", "tunisia", "tonga", "turkey", "trinidadandTobago", "tuvalu", "taiwanProvinceofChina", "tanzaniaUnitedRepublicof", "ukraine", "uganda", "unitedStatesMinorOutlyingIslands", "unitedStatesofAmerica", "uruguay", "uzbekistan", "holySee", "saintVincentandtheGrenadines", "venezuelaBolivarianRepublicof", "virginIslandsBritish", "virginIslandsUS", "vietNam", "vanuatu", "wallisandFutuna", "samoa", "yemen", "mayotte", "southAfrica", "zambia", "zimbabwe"]  # noqa: E501
        if ucr_country not in allowed_values:
            raise ValueError(
                "Invalid value for `ucr_country` ({0}), must be one of {1}"  # noqa: E501
                .format(ucr_country, allowed_values)
            )

        self._ucr_country = ucr_country

    @property
    def amount(self):
        """Gets the amount of this BillingData.  # noqa: E501


        :return: The amount of this BillingData.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BillingData.


        :param amount: The amount of this BillingData.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this BillingData.  # noqa: E501


        :return: The currency of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this BillingData.


        :param currency: The currency of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["cHF", "eUR"]  # noqa: E501
        if currency not in allowed_values:
            raise ValueError(
                "Invalid value for `currency` ({0}), must be one of {1}"  # noqa: E501
                .format(currency, allowed_values)
            )

        self._currency = currency

    @property
    def ud_address_type(self):
        """Gets the ud_address_type of this BillingData.  # noqa: E501


        :return: The ud_address_type of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_address_type

    @ud_address_type.setter
    def ud_address_type(self, ud_address_type):
        """Sets the ud_address_type of this BillingData.


        :param ud_address_type: The ud_address_type of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["s", "k"]  # noqa: E501
        if ud_address_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ud_address_type` ({0}), must be one of {1}"  # noqa: E501
                .format(ud_address_type, allowed_values)
            )

        self._ud_address_type = ud_address_type

    @property
    def ud_name(self):
        """Gets the ud_name of this BillingData.  # noqa: E501


        :return: The ud_name of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_name

    @ud_name.setter
    def ud_name(self, ud_name):
        """Sets the ud_name of this BillingData.


        :param ud_name: The ud_name of this BillingData.  # noqa: E501
        :type: str
        """
        if ud_name is not None and len(ud_name) > 70:
            raise ValueError("Invalid value for `ud_name`, length must be less than or equal to `70`")  # noqa: E501

        self._ud_name = ud_name

    @property
    def ud_street_or_address_line1(self):
        """Gets the ud_street_or_address_line1 of this BillingData.  # noqa: E501


        :return: The ud_street_or_address_line1 of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_street_or_address_line1

    @ud_street_or_address_line1.setter
    def ud_street_or_address_line1(self, ud_street_or_address_line1):
        """Sets the ud_street_or_address_line1 of this BillingData.


        :param ud_street_or_address_line1: The ud_street_or_address_line1 of this BillingData.  # noqa: E501
        :type: str
        """
        if ud_street_or_address_line1 is not None and len(ud_street_or_address_line1) > 70:
            raise ValueError("Invalid value for `ud_street_or_address_line1`, length must be less than or equal to `70`")  # noqa: E501

        self._ud_street_or_address_line1 = ud_street_or_address_line1

    @property
    def ud_build_no_or_address_line2(self):
        """Gets the ud_build_no_or_address_line2 of this BillingData.  # noqa: E501


        :return: The ud_build_no_or_address_line2 of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_build_no_or_address_line2

    @ud_build_no_or_address_line2.setter
    def ud_build_no_or_address_line2(self, ud_build_no_or_address_line2):
        """Sets the ud_build_no_or_address_line2 of this BillingData.


        :param ud_build_no_or_address_line2: The ud_build_no_or_address_line2 of this BillingData.  # noqa: E501
        :type: str
        """
        if ud_build_no_or_address_line2 is not None and len(ud_build_no_or_address_line2) > 70:
            raise ValueError("Invalid value for `ud_build_no_or_address_line2`, length must be less than or equal to `70`")  # noqa: E501

        self._ud_build_no_or_address_line2 = ud_build_no_or_address_line2

    @property
    def ud_postal_code(self):
        """Gets the ud_postal_code of this BillingData.  # noqa: E501


        :return: The ud_postal_code of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_postal_code

    @ud_postal_code.setter
    def ud_postal_code(self, ud_postal_code):
        """Sets the ud_postal_code of this BillingData.


        :param ud_postal_code: The ud_postal_code of this BillingData.  # noqa: E501
        :type: str
        """
        if ud_postal_code is not None and len(ud_postal_code) > 16:
            raise ValueError("Invalid value for `ud_postal_code`, length must be less than or equal to `16`")  # noqa: E501

        self._ud_postal_code = ud_postal_code

    @property
    def ud_city(self):
        """Gets the ud_city of this BillingData.  # noqa: E501


        :return: The ud_city of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_city

    @ud_city.setter
    def ud_city(self, ud_city):
        """Sets the ud_city of this BillingData.


        :param ud_city: The ud_city of this BillingData.  # noqa: E501
        :type: str
        """
        if ud_city is not None and len(ud_city) > 35:
            raise ValueError("Invalid value for `ud_city`, length must be less than or equal to `35`")  # noqa: E501

        self._ud_city = ud_city

    @property
    def ud_country(self):
        """Gets the ud_country of this BillingData.  # noqa: E501


        :return: The ud_country of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._ud_country

    @ud_country.setter
    def ud_country(self, ud_country):
        """Sets the ud_country of this BillingData.


        :param ud_country: The ud_country of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["andorra", "unitedArabEmirates", "afghanistan", "antiguaandBarbuda", "anguilla", "albania", "armenia", "angola", "antarctica", "argentina", "americanSamoa", "austria", "australia", "aruba", "ålandIslands", "azerbaijan", "bosniaandHerzegovina", "barbados", "bangladesh", "belgium", "burkinaFaso", "bulgaria", "bahrain", "burundi", "benin", "saintBarthélemy", "bermuda", "bruneiDarussalam", "boliviaPlurinationalStateof", "bonaireSintEustatiusandSaba", "brazil", "bahamas", "bhutan", "bouvetIsland", "botswana", "belarus", "belize", "canada", "cocosKeelingIslands", "congoDemocraticRepublicofthe", "centralAfricanRepublic", "congo", "switzerland", "côtedIvoire", "cookIslands", "chile", "cameroon", "china", "colombia", "costaRica", "cuba", "caboVerde", "curaçao", "christmasIsland", "cyprus", "czechia", "germany", "djibouti", "denmark", "dominica", "dominicanRepublic", "algeria", "ecuador", "estonia", "egypt", "westernSahara", "eritrea", "spain", "ethiopia", "finland", "fiji", "falklandIslandsMalvinas", "micronesiaFederatedStatesof", "faroeIslands", "france", "gabon", "unitedKingdomofGreatBritainandNorthernIreland", "grenada", "georgia", "frenchGuiana", "guernsey", "ghana", "gibraltar", "greenland", "gambia", "guinea", "guadeloupe", "equatorialGuinea", "greece", "southGeorgiaandtheSouthSandwichIslands", "guatemala", "guam", "guineaBissau", "guyana", "hongKong", "heardIslandandMcDonaldIslands", "honduras", "croatia", "haiti", "hungary", "indonesia", "ireland", "israel", "isleofMan", "india", "britishIndianOceanTerritory", "iraq", "iranIslamicRepublicof", "iceland", "italy", "jersey", "jamaica", "jordan", "japan", "kenya", "kyrgyzstan", "cambodia", "kiribati", "comoros", "saintKittsandNevis", "koreaDemocraticPeoplesRepublicof", "koreaRepublicof", "kuwait", "caymanIslands", "kazakhstan", "laoPeoplesDemocraticRepublic", "lebanon", "saintLucia", "liechtenstein", "sriLanka", "liberia", "lesotho", "lithuania", "luxembourg", "latvia", "libya", "morocco", "monaco", "moldovaRepublicof", "montenegro", "saintMartinFrenchpart", "madagascar", "marshallIslands", "northMacedonia", "mali", "myanmar", "mongolia", "macao", "northernMarianaIslands", "martinique", "mauritania", "montserrat", "malta", "mauritius", "maldives", "malawi", "mexico", "malaysia", "mozambique", "namibia", "newCaledonia", "niger", "norfolkIsland", "nigeria", "nicaragua", "netherlands", "norway", "nepal", "nauru", "niue", "newZealand", "oman", "panama", "peru", "frenchPolynesia", "papuaNewGuinea", "philippines", "pakistan", "poland", "saintPierreandMiquelon", "pitcairn", "puertoRico", "palestineStateof", "portugal", "palau", "paraguay", "qatar", "réunion", "romania", "serbia", "russianFederation", "rwanda", "saudiArabia", "solomonIslands", "seychelles", "sudan", "sweden", "singapore", "saintHelenaAscensionandTristandaCunha", "slovenia", "svalbardandJanMayen", "slovakia", "sierraLeone", "sanMarino", "senegal", "somalia", "suriname", "southSudan", "saoTomeandPrincipe", "elSalvador", "sintMaartenDutchpart", "syrianArabRepublic", "eswatini", "turksandCaicosIslands", "chad", "frenchSouthernTerritories", "togo", "thailand", "tajikistan", "tokelau", "timorLeste", "turkmenistan", "tunisia", "tonga", "turkey", "trinidadandTobago", "tuvalu", "taiwanProvinceofChina", "tanzaniaUnitedRepublicof", "ukraine", "uganda", "unitedStatesMinorOutlyingIslands", "unitedStatesofAmerica", "uruguay", "uzbekistan", "holySee", "saintVincentandtheGrenadines", "venezuelaBolivarianRepublicof", "virginIslandsBritish", "virginIslandsUS", "vietNam", "vanuatu", "wallisandFutuna", "samoa", "yemen", "mayotte", "southAfrica", "zambia", "zimbabwe"]  # noqa: E501
        if ud_country not in allowed_values:
            raise ValueError(
                "Invalid value for `ud_country` ({0}), must be one of {1}"  # noqa: E501
                .format(ud_country, allowed_values)
            )

        self._ud_country = ud_country

    @property
    def reference_type(self):
        """Gets the reference_type of this BillingData.  # noqa: E501


        :return: The reference_type of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._reference_type

    @reference_type.setter
    def reference_type(self, reference_type):
        """Sets the reference_type of this BillingData.


        :param reference_type: The reference_type of this BillingData.  # noqa: E501
        :type: str
        """
        allowed_values = ["qRR", "sCOR", "nON"]  # noqa: E501
        if reference_type not in allowed_values:
            raise ValueError(
                "Invalid value for `reference_type` ({0}), must be one of {1}"  # noqa: E501
                .format(reference_type, allowed_values)
            )

        self._reference_type = reference_type

    @property
    def reference(self):
        """Gets the reference of this BillingData.  # noqa: E501


        :return: The reference of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this BillingData.


        :param reference: The reference of this BillingData.  # noqa: E501
        :type: str
        """
        if reference is not None and len(reference) > 27:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `27`")  # noqa: E501

        self._reference = reference

    @property
    def unstructured_message(self):
        """Gets the unstructured_message of this BillingData.  # noqa: E501


        :return: The unstructured_message of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._unstructured_message

    @unstructured_message.setter
    def unstructured_message(self, unstructured_message):
        """Sets the unstructured_message of this BillingData.


        :param unstructured_message: The unstructured_message of this BillingData.  # noqa: E501
        :type: str
        """
        if unstructured_message is not None and len(unstructured_message) > 140:
            raise ValueError("Invalid value for `unstructured_message`, length must be less than or equal to `140`")  # noqa: E501

        self._unstructured_message = unstructured_message

    @property
    def billing_info(self):
        """Gets the billing_info of this BillingData.  # noqa: E501


        :return: The billing_info of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._billing_info

    @billing_info.setter
    def billing_info(self, billing_info):
        """Sets the billing_info of this BillingData.


        :param billing_info: The billing_info of this BillingData.  # noqa: E501
        :type: str
        """
        if billing_info is not None and len(billing_info) > 140:
            raise ValueError("Invalid value for `billing_info`, length must be less than or equal to `140`")  # noqa: E501

        self._billing_info = billing_info

    @property
    def av1_parameters(self):
        """Gets the av1_parameters of this BillingData.  # noqa: E501


        :return: The av1_parameters of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._av1_parameters

    @av1_parameters.setter
    def av1_parameters(self, av1_parameters):
        """Sets the av1_parameters of this BillingData.


        :param av1_parameters: The av1_parameters of this BillingData.  # noqa: E501
        :type: str
        """
        if av1_parameters is not None and len(av1_parameters) > 100:
            raise ValueError("Invalid value for `av1_parameters`, length must be less than or equal to `100`")  # noqa: E501

        self._av1_parameters = av1_parameters

    @property
    def av2_parameters(self):
        """Gets the av2_parameters of this BillingData.  # noqa: E501


        :return: The av2_parameters of this BillingData.  # noqa: E501
        :rtype: str
        """
        return self._av2_parameters

    @av2_parameters.setter
    def av2_parameters(self, av2_parameters):
        """Sets the av2_parameters of this BillingData.


        :param av2_parameters: The av2_parameters of this BillingData.  # noqa: E501
        :type: str
        """
        if av2_parameters is not None and len(av2_parameters) > 100:
            raise ValueError("Invalid value for `av2_parameters`, length must be less than or equal to `100`")  # noqa: E501

        self._av2_parameters = av2_parameters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BillingData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BillingData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class MailMergeDocAction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_print': 'bool',
        'print_package': 'str',
        'envelope_delivery': 'str',
        'envelope_type': 'str',
        'print_pool': 'str',
        'country': 'str',
        'receiver_id': 'str',
        'action_id': 'str'
    }

    attribute_map = {
        '_print': 'print',
        'print_package': 'printPackage',
        'envelope_delivery': 'envelopeDelivery',
        'envelope_type': 'envelopeType',
        'print_pool': 'printPool',
        'country': 'country',
        'receiver_id': 'receiverId',
        'action_id': 'actionId'
    }

    def __init__(self, _print=None, print_package=None, envelope_delivery=None, envelope_type=None, print_pool=None, country=None, receiver_id=None, action_id=None):  # noqa: E501
        """MailMergeDocAction - a model defined in Swagger"""  # noqa: E501

        self.__print = None
        self._print_package = None
        self._envelope_delivery = None
        self._envelope_type = None
        self._print_pool = None
        self._country = None
        self._receiver_id = None
        self._action_id = None
        self.discriminator = None

        if _print is not None:
            self._print = _print
        if print_package is not None:
            self.print_package = print_package
        if envelope_delivery is not None:
            self.envelope_delivery = envelope_delivery
        if envelope_type is not None:
            self.envelope_type = envelope_type
        if print_pool is not None:
            self.print_pool = print_pool
        if country is not None:
            self.country = country
        if receiver_id is not None:
            self.receiver_id = receiver_id
        if action_id is not None:
            self.action_id = action_id

    @property
    def _print(self):
        """Gets the _print of this MailMergeDocAction.  # noqa: E501


        :return: The _print of this MailMergeDocAction.  # noqa: E501
        :rtype: bool
        """
        return self.__print

    @_print.setter
    def _print(self, _print):
        """Sets the _print of this MailMergeDocAction.


        :param _print: The _print of this MailMergeDocAction.  # noqa: E501
        :type: bool
        """

        self.__print = _print

    @property
    def print_package(self):
        """Gets the print_package of this MailMergeDocAction.  # noqa: E501


        :return: The print_package of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._print_package

    @print_package.setter
    def print_package(self, print_package):
        """Sets the print_package of this MailMergeDocAction.


        :param print_package: The print_package of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._print_package = print_package

    @property
    def envelope_delivery(self):
        """Gets the envelope_delivery of this MailMergeDocAction.  # noqa: E501


        :return: The envelope_delivery of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._envelope_delivery

    @envelope_delivery.setter
    def envelope_delivery(self, envelope_delivery):
        """Sets the envelope_delivery of this MailMergeDocAction.


        :param envelope_delivery: The envelope_delivery of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._envelope_delivery = envelope_delivery

    @property
    def envelope_type(self):
        """Gets the envelope_type of this MailMergeDocAction.  # noqa: E501


        :return: The envelope_type of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._envelope_type

    @envelope_type.setter
    def envelope_type(self, envelope_type):
        """Sets the envelope_type of this MailMergeDocAction.


        :param envelope_type: The envelope_type of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._envelope_type = envelope_type

    @property
    def print_pool(self):
        """Gets the print_pool of this MailMergeDocAction.  # noqa: E501


        :return: The print_pool of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._print_pool

    @print_pool.setter
    def print_pool(self, print_pool):
        """Sets the print_pool of this MailMergeDocAction.


        :param print_pool: The print_pool of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._print_pool = print_pool

    @property
    def country(self):
        """Gets the country of this MailMergeDocAction.  # noqa: E501


        :return: The country of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this MailMergeDocAction.


        :param country: The country of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def receiver_id(self):
        """Gets the receiver_id of this MailMergeDocAction.  # noqa: E501


        :return: The receiver_id of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._receiver_id

    @receiver_id.setter
    def receiver_id(self, receiver_id):
        """Sets the receiver_id of this MailMergeDocAction.


        :param receiver_id: The receiver_id of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._receiver_id = receiver_id

    @property
    def action_id(self):
        """Gets the action_id of this MailMergeDocAction.  # noqa: E501


        :return: The action_id of this MailMergeDocAction.  # noqa: E501
        :rtype: str
        """
        return self._action_id

    @action_id.setter
    def action_id(self, action_id):
        """Sets the action_id of this MailMergeDocAction.


        :param action_id: The action_id of this MailMergeDocAction.  # noqa: E501
        :type: str
        """

        self._action_id = action_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MailMergeDocAction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MailMergeDocAction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PdfResources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'doc_metadata': 'DocMetadata',
        'outlines': 'list[PdfOutline]',
        'xmp_metadata': 'str',
        'images': 'list[Document]',
        'text': 'list[Document]'
    }

    attribute_map = {
        'doc_metadata': 'DocMetadata',
        'outlines': 'outlines',
        'xmp_metadata': 'xmpMetadata',
        'images': 'images',
        'text': 'text'
    }

    def __init__(self, doc_metadata=None, outlines=None, xmp_metadata=None, images=None, text=None):  # noqa: E501
        """PdfResources - a model defined in Swagger"""  # noqa: E501

        self._doc_metadata = None
        self._outlines = None
        self._xmp_metadata = None
        self._images = None
        self._text = None
        self.discriminator = None

        if doc_metadata is not None:
            self.doc_metadata = doc_metadata
        if outlines is not None:
            self.outlines = outlines
        if xmp_metadata is not None:
            self.xmp_metadata = xmp_metadata
        if images is not None:
            self.images = images
        if text is not None:
            self.text = text

    @property
    def doc_metadata(self):
        """Gets the doc_metadata of this PdfResources.  # noqa: E501


        :return: The doc_metadata of this PdfResources.  # noqa: E501
        :rtype: DocMetadata
        """
        return self._doc_metadata

    @doc_metadata.setter
    def doc_metadata(self, doc_metadata):
        """Sets the doc_metadata of this PdfResources.


        :param doc_metadata: The doc_metadata of this PdfResources.  # noqa: E501
        :type: DocMetadata
        """

        self._doc_metadata = doc_metadata

    @property
    def outlines(self):
        """Gets the outlines of this PdfResources.  # noqa: E501


        :return: The outlines of this PdfResources.  # noqa: E501
        :rtype: list[PdfOutline]
        """
        return self._outlines

    @outlines.setter
    def outlines(self, outlines):
        """Sets the outlines of this PdfResources.


        :param outlines: The outlines of this PdfResources.  # noqa: E501
        :type: list[PdfOutline]
        """

        self._outlines = outlines

    @property
    def xmp_metadata(self):
        """Gets the xmp_metadata of this PdfResources.  # noqa: E501


        :return: The xmp_metadata of this PdfResources.  # noqa: E501
        :rtype: str
        """
        return self._xmp_metadata

    @xmp_metadata.setter
    def xmp_metadata(self, xmp_metadata):
        """Sets the xmp_metadata of this PdfResources.


        :param xmp_metadata: The xmp_metadata of this PdfResources.  # noqa: E501
        :type: str
        """

        self._xmp_metadata = xmp_metadata

    @property
    def images(self):
        """Gets the images of this PdfResources.  # noqa: E501


        :return: The images of this PdfResources.  # noqa: E501
        :rtype: list[Document]
        """
        return self._images

    @images.setter
    def images(self, images):
        """Sets the images of this PdfResources.


        :param images: The images of this PdfResources.  # noqa: E501
        :type: list[Document]
        """

        self._images = images

    @property
    def text(self):
        """Gets the text of this PdfResources.  # noqa: E501


        :return: The text of this PdfResources.  # noqa: E501
        :rtype: list[Document]
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this PdfResources.


        :param text: The text of this PdfResources.  # noqa: E501
        :type: list[Document]
        """

        self._text = text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PdfResources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PdfResources):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pdf4me

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SwissQrCreatorListRes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'swiss_qr_creator_res_list': 'list[SwissQrCreatorRes]',
        'trace_id': 'str',
        'job_id': 'str',
        'subscription_usage': 'SubscriptionUsage'
    }

    attribute_map = {
        'swiss_qr_creator_res_list': 'swissQrCreatorResList',
        'trace_id': 'traceId',
        'job_id': 'jobId',
        'subscription_usage': 'subscriptionUsage'
    }

    def __init__(self, swiss_qr_creator_res_list=None, trace_id=None, job_id=None, subscription_usage=None):  # noqa: E501
        """SwissQrCreatorListRes - a model defined in Swagger"""  # noqa: E501

        self._swiss_qr_creator_res_list = None
        self._trace_id = None
        self._job_id = None
        self._subscription_usage = None
        self.discriminator = None

        if swiss_qr_creator_res_list is not None:
            self.swiss_qr_creator_res_list = swiss_qr_creator_res_list
        if trace_id is not None:
            self.trace_id = trace_id
        if job_id is not None:
            self.job_id = job_id
        if subscription_usage is not None:
            self.subscription_usage = subscription_usage

    @property
    def swiss_qr_creator_res_list(self):
        """Gets the swiss_qr_creator_res_list of this SwissQrCreatorListRes.  # noqa: E501


        :return: The swiss_qr_creator_res_list of this SwissQrCreatorListRes.  # noqa: E501
        :rtype: list[SwissQrCreatorRes]
        """
        return self._swiss_qr_creator_res_list

    @swiss_qr_creator_res_list.setter
    def swiss_qr_creator_res_list(self, swiss_qr_creator_res_list):
        """Sets the swiss_qr_creator_res_list of this SwissQrCreatorListRes.


        :param swiss_qr_creator_res_list: The swiss_qr_creator_res_list of this SwissQrCreatorListRes.  # noqa: E501
        :type: list[SwissQrCreatorRes]
        """

        self._swiss_qr_creator_res_list = swiss_qr_creator_res_list

    @property
    def trace_id(self):
        """Gets the trace_id of this SwissQrCreatorListRes.  # noqa: E501


        :return: The trace_id of this SwissQrCreatorListRes.  # noqa: E501
        :rtype: str
        """
        return self._trace_id

    @trace_id.setter
    def trace_id(self, trace_id):
        """Sets the trace_id of this SwissQrCreatorListRes.


        :param trace_id: The trace_id of this SwissQrCreatorListRes.  # noqa: E501
        :type: str
        """

        self._trace_id = trace_id

    @property
    def job_id(self):
        """Gets the job_id of this SwissQrCreatorListRes.  # noqa: E501


        :return: The job_id of this SwissQrCreatorListRes.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this SwissQrCreatorListRes.


        :param job_id: The job_id of this SwissQrCreatorListRes.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def subscription_usage(self):
        """Gets the subscription_usage of this SwissQrCreatorListRes.  # noqa: E501


        :return: The subscription_usage of this SwissQrCreatorListRes.  # noqa: E501
        :rtype: SubscriptionUsage
        """
        return self._subscription_usage

    @subscription_usage.setter
    def subscription_usage(self, subscription_usage):
        """Sets the subscription_usage of this SwissQrCreatorListRes.


        :param subscription_usage: The subscription_usage of this SwissQrCreatorListRes.  # noqa: E501
        :type: SubscriptionUsage
        """

        self._subscription_usage = subscription_usage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SwissQrCreatorListRes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwissQrCreatorListRes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
